@@ -52,9 +52,10 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::loader;
 using namespace com::sun::star::lang;
 using namespace osl;
-using namespace rtl;
 using namespace cppu;
 
+using ::rtl::OUString;
+
 #if OSL_DEBUG_LEVEL > 0
 #define TEST_ENSHURE(c, m)   OSL_ENSURE(c, m)
 #else
@@ -91,7 +92,7 @@ SAL_IMPLEMENT_MAIN()
     {
         // try to get provider from module
         component_getFactoryFunc pCompFactoryFunc = (component_getFactoryFunc)
-            module.getFunctionSymbol( OUString::createFromAscii(COMPONENT_GETFACTORY) );
+            module.getFunctionSymbol( OUString(RTL_CONSTASCII_USTRINGPARAM(COMPONENT_GETFACTORY)) );
 
         if (pCompFactoryFunc)
         {
